from .mlt.MalteseNewsClassification import *
from .multilingual.MultiEURLEXMultilabelClassification import *
from .por.BrazilianToxicTweetsClassification import *
from .rus.CEDRClassification import *
from .rus.SensitiveTopicsClassification import *
